@@ -75,7 +75,7 @@ $EXPORT_TAGS{'all'} = [ @{ $EXPORT_TAGS{'constants'} },
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(  );
-our $VERSION = '2.05'; # version template
+our $VERSION = '2.06'; # version template
 
 BEGIN {
 require Treex::PML::IO;
@@ -489,7 +489,7 @@ sub get_all {
 	    $1<0 ? $val->elements_list->[$1] : undef; # element
 	  $val ?
 	    (defined $2 and length $2) ?
-	      ($val->[0] eq $2) ? ($val) : ()
+	      ($val->[0] eq $2) ? ($val->[1]) : ()
 	    : $val->[1]
 	  :()
 	} elsif ($step =~ /^([^\[]+)(?:\[([-+]?\d+)\])?/) {
